Element type codes for mgpuReadAsyncToPort.
Deliberately NOT BufferDataType.index: the Dart and C++ BufferDataType
enums are ordered DIFFERENTLY, so an index crossing the FFI boundary is
ambiguous. These values match MGPUElementType in src/include/minigpu.h.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited